
/* This file is generated by glib-mkenums, do not modify it. This code is licensed under the same license as the containing project. Note that it links to GLib, so must comply with the LGPL linking clauses. */

#pragma once

#include <glib-object.h>

G_BEGIN_DECLS

/* enumerations from "goabackendenums.h" */

GType goa_provider_group_get_type (void);
#define GOA_TYPE_PROVIDER_GROUP (goa_provider_group_get_type())

GType goa_provider_features_get_type (void);
#define GOA_TYPE_PROVIDER_FEATURES (goa_provider_features_get_type())

G_END_DECLS

/* Generated data ends here */

